# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/jobs/job.proto\x12$qwak.feature.store.execution.v1.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/execution/v1/backfill.proto\"\xc0\x05\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x17\n\rlegacy_run_id\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x65xecution_id\x18\x03 \x01(\tH\x00\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x04 \x01(\t\x12\x15\n\rfeatureset_id\x18\x05 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\t\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12\x43\n\njob_status\x18\x08 \x01(\x0e\x32/.qwak.feature.store.execution.v1.jobs.JobStatus\x12\x31\n\rcreation_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x0cjob_metadata\x18\x0c \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.jobs.JobMetadata\x12R\n\njob_labels\x18\r \x03(\x0b\x32>.qwak.feature.store.execution.v1.jobs.JobRecord.JobLabelsEntry\x12\x0c\n\x04\x63ode\x18\x0e \x01(\t\x12H\n\x04info\x18\x0f \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.jobs.FailureInformationH\x01\x1a\x30\n\x0eJobLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x65xec_idB\x0e\n\x0c\x66\x61ilure_info\"\xad\x03\n\x0bJobMetadata\x12`\n\x18\x62\x61tch_ingestion_metadata\x18\x01 \x01(\x0b\x32<.qwak.feature.store.execution.v1.jobs.BatchIngestionMetadataH\x00\x12h\n!batch_backfill_ingestion_metadata\x18\x02 \x01(\x0b\x32;.qwak.feature.store.execution.v1.jobs.BatchBackfillMetadataH\x00\x12^\n\x17\x62\x61tch_deletion_metadata\x18\x03 \x01(\x0b\x32;.qwak.feature.store.execution.v1.jobs.BatchDeletionMetadataH\x00\x12\x44\n\x1e\x65xpiration_watermark_timestamp\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x42\x0f\n\rmetadata_typeB\x1b\n\x19\x64\x61ta_retention_state_type\"\x9d\x01\n\x15\x42\x61tchDeletionMetadata\x12!\n\x19\x64\x65letion_candidates_table\x18\x01 \x01(\t\x12\x32\n*deletion_candidates_size_in_bytes_on_redis\x18\x02 \x01(\x03\x12-\n%billing_size_in_bytes_before_deletion\x18\x03 \x01(\x03\"\xe7\x01\n\x16\x42\x61tchIngestionMetadata\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x38\n\x14\x62\x61tch_execution_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd6\x03\n\x15\x42\x61tchBackfillMetadata\x12\x19\n\x11num_interval_rows\x18\x01 \x01(\x03\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x41\n\x1doffline_processing_start_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1boffline_processing_end_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1conline_processing_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1aonline_processing_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17last_batch_logical_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"b\n\x12\x46\x61ilureInformation\x12\x1e\n\x16original_error_message\x18\x01 \x01(\t\x12\x11\n\x07message\x18\x02 \x01(\tH\x00\x42\x19\n\x17\x66ormatted_error_message*\xac\x01\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x18\n\x14JOB_STATUS_COMPLETED\x10\x03\x12\x15\n\x11JOB_STATUS_FAILED\x10\x04\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x05\x12\x1d\n\x19LEGACY_JOB_STATUS_RUNNING\x10\x06\x12\x1d\n\x19LEGACY_JOB_STATUS_PENDING\x10\x07\x42G\n*com.qwak.ai.features.execution.api.v1.jobsP\x01Z\x17qwak/fsexecution;fsjobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.jobs.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.features.execution.api.v1.jobsP\001Z\027qwak/fsexecution;fsjobs'
  _JOBRECORD_JOBLABELSENTRY._options = None
  _JOBRECORD_JOBLABELSENTRY._serialized_options = b'8\001'
  _globals['_JOBSTATUS']._serialized_start=2248
  _globals['_JOBSTATUS']._serialized_end=2420
  _globals['_JOBRECORD']._serialized_start=142
  _globals['_JOBRECORD']._serialized_end=846
  _globals['_JOBRECORD_JOBLABELSENTRY']._serialized_start=771
  _globals['_JOBRECORD_JOBLABELSENTRY']._serialized_end=819
  _globals['_JOBMETADATA']._serialized_start=849
  _globals['_JOBMETADATA']._serialized_end=1278
  _globals['_BATCHDELETIONMETADATA']._serialized_start=1281
  _globals['_BATCHDELETIONMETADATA']._serialized_end=1438
  _globals['_BATCHINGESTIONMETADATA']._serialized_start=1441
  _globals['_BATCHINGESTIONMETADATA']._serialized_end=1672
  _globals['_BATCHBACKFILLMETADATA']._serialized_start=1675
  _globals['_BATCHBACKFILLMETADATA']._serialized_end=2145
  _globals['_FAILUREINFORMATION']._serialized_start=2147
  _globals['_FAILUREINFORMATION']._serialized_end=2245
# @@protoc_insertion_point(module_scope)
