# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build/v1/build.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19qwak/build/v1/build.proto\x12\x11\x63om.qwak.build.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17qwak/builds/build.proto\"\xda\x01\n\x0bModelSchema\x12+\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.com.qwak.build.v1.Entity\x12,\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1a.com.qwak.build.v1.Feature\x12\x32\n\x0bpredictions\x18\x03 \x03(\x0b\x32\x1d.com.qwak.build.v1.Prediction\x12<\n\x10inference_output\x18\x04 \x03(\x0b\x32\".com.qwak.build.v1.InferenceOutput\"B\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa8\x04\n\x07\x46\x65\x61ture\x12\x38\n\rbatch_feature\x18\x01 \x01(\x0b\x32\x1f.com.qwak.build.v1.BatchFeatureH\x00\x12>\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12@\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\".com.qwak.build.v1.OnTheFlyFeatureH\x00\x12@\n\x11streaming_feature\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.StreamingFeatureH\x00\x12\x38\n\rrequest_input\x18\x05 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x12W\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32..com.qwak.build.v1.StreamingAggregationFeatureH\x00\x12=\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32!.com.qwak.build.v1.BatchFeatureV1H\x00\x12\x45\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32%.com.qwak.build.v1.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x85\x01\n\x0fOnTheFlyFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x0fsource_features\x18\x03 \x03(\x0b\x32 .com.qwak.build.v1.SourceFeature\"I\n\x0e\x42\x61tchFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x12StreamingFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"G\n\x0c\x42\x61tchFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x10StreamingFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1bStreamingAggregationFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"H\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\x91\x01\n\rSourceFeature\x12>\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12\x38\n\rrequest_input\x18\x02 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x42\x06\n\x04type\"F\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"K\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa1\x01\n\tValueType\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".com.qwak.build.v1.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"\x9c\x07\n\x05\x42uild\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x10\n\x08\x63ommitId\x18\x02 \x01(\t\x12\x10\n\x08\x62ranchId\x18\x03 \x01(\t\x12\x13\n\x0b\x62uildConfig\x18\x04 \x01(\t\x12\x34\n\x0c\x62uild_status\x18\x05 \x01(\x0e\x32\x1e.com.qwak.build.v1.BuildStatus\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\r\n\x05steps\x18\x07 \x03(\t\x12\x34\n\x06params\x18\x08 \x03(\x0b\x32$.com.qwak.build.v1.Build.ParamsEntry\x12\x36\n\x07metrics\x18\t \x03(\x0b\x32%.com.qwak.build.v1.Build.MetricsEntry\x12\x34\n\x0cmodel_schema\x18\n \x01(\x0b\x32\x1e.com.qwak.build.v1.ModelSchema\x12\'\n\x05\x61udit\x18\x0b \x01(\x0b\x32\x18.com.qwak.build.v1.Audit\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12J\n\x1b\x62uild_configuration_message\x18\x0f \x01(\x0b\x32%.com.qwak.build.v1.BuildConfiguration\x12,\n\x08\x65nd_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x65nvironment_id\x18\x11 \x01(\t\x12\x1c\n\x14\x62uild_destined_image\x18\x12 \x01(\t\x12;\n\x10\x66ramework_models\x18\x13 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\x12(\n build_destined_image_pull_secret\x18\x14 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x15 \x01(\t\x12\x12\n\nbuild_name\x18\x16 \x01(\t\x12\x15\n\rbuild_version\x18\x17 \x01(\x03\x12\x10\n\x08\x64uration\x18\x18 \x01(\x03\x12\x18\n\x10model_version_id\x18\x19 \x01(\t\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x9b\x01\n\x05\x41udit\x12\x12\n\ncreated_by\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x03 \x01(\t\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb3\x02\n\x12\x42uildConfiguration\x12<\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.BuildProperties\x12\x36\n\tbuild_env\x18\x02 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x36\n\tpre_build\x18\x03 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x37\n\npost_build\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12%\n\x04step\x18\x05 \x01(\x0b\x32\x17.com.qwak.build.v1.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"\xba\x01\n\x0f\x42uildProperties\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x33\n\tmodel_uri\x18\x02 \x01(\x0b\x32 .com.qwak.build.v1.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xd4\x01\n\x10\x42uildEnvironment\x12.\n\x06\x64ocker\x18\x01 \x01(\x0b\x32\x1e.com.qwak.build.v1.DockerBuild\x12,\n\x05local\x18\x02 \x01(\x0b\x32\x1d.com.qwak.build.v1.LocalBuild\x12\x32\n\npython_env\x18\x03 \x01(\x0b\x32\x1e.com.qwak.build.v1.PythonBuild\x12.\n\x06remote\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.RemoteBuild\"\xae\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x41\n\nbuild_args\x18\x02 \x03(\x0b\x32-.com.qwak.build.v1.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x12\'\n\x1fservice_account_key_secret_name\x18\t \x01(\t\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x8c\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12>\n\nvirtualenv\x18\x02 \x01(\x0b\x32*.com.qwak.build.v1.VirtualEnvironmentBuild\x12,\n\x05\x63onda\x18\x03 \x01(\x0b\x32\x1d.com.qwak.build.v1.CondaBuild\x12.\n\x06poetry\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"\\\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12:\n\tresources\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xf7\x01\n\x0b\x42uildFilter\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x37\n\x0emetric_filters\x18\x02 \x03(\x0b\x32\x1f.com.qwak.build.v1.MetricFilter\x12=\n\x11parameter_filters\x18\x03 \x03(\x0b\x32\".com.qwak.build.v1.ParameterFilter\x12\x18\n\x10require_all_tags\x18\x04 \x01(\x08\x12\x1a\n\x12include_extra_tags\x18\x05 \x01(\x08\x12\x11\n\tbuild_ids\x18\x06 \x03(\t\x12\x19\n\x11model_version_ids\x18\x07 \x03(\t\"r\n\x0cMetricFilter\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12\x14\n\x0cmetric_value\x18\x02 \x01(\x02\x12\x37\n\x08operator\x18\x03 \x01(\x0e\x32%.com.qwak.build.v1.MetricOperatorType\"~\n\x0fParameterFilter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x17\n\x0fparameter_value\x18\x02 \x01(\t\x12:\n\x08operator\x18\x03 \x01(\x0e\x32(.com.qwak.build.v1.ParameterOperatorType\"d\n\x13\x46rameworkModelsSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12;\n\x10\x66ramework_models\x18\x02 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\"c\n\x0e\x46rameworkModel\x12I\n\x16huggingface_model_spec\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.HuggingFaceModelSpecH\x00\x42\x06\n\x04type\"]\n\x14HuggingFaceModelSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x0c\n\x04sha1\x18\x04 \x01(\t\"r\n\x11ScanResultSummary\x12(\n\x06issues\x18\x01 \x03(\x0b\x32\x18.com.qwak.build.v1.Issue\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\x12\x1b\n\x13ui_scan_direct_link\x18\x03 \x01(\t\"a\n\x05Issue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08severity\x18\x02 \x01(\t\x12\x12\n\nissue_type\x18\x03 \x01(\t\x12\x0f\n\x07summary\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"L\n\x11\x42uildImageDetails\x12\x17\n\x0fimage_full_path\x18\x01 \x01(\t\x12\x1e\n\x16image_pull_secret_name\x18\x02 \x01(\t\"\x9b\x04\n\x0fScanRequestType\x12\\\n scan_software_components_request\x18\x01 \x01(\x0b\x32\x30.com.qwak.build.v1.ScanSoftwareComponentsRequestH\x00\x12U\n\x1cscan_vulnerabilities_request\x18\x02 \x01(\x0b\x32-.com.qwak.build.v1.ScanVulnerabilitiesRequestH\x00\x12Z\n\x1fscan_malicious_packages_request\x18\x03 \x01(\x0b\x32/.com.qwak.build.v1.ScanMaliciousPackagesRequestH\x00\x12X\n\x1escan_policy_violations_request\x18\x04 \x01(\x0b\x32..com.qwak.build.v1.ScanPolicyViolationsRequestH\x00\x12\x43\n\x13scan_status_request\x18\x05 \x01(\x0b\x32$.com.qwak.build.v1.ScanStatusRequestH\x00\x12P\n\x1ascan_feature_state_request\x18\x06 \x01(\x0b\x32*.com.qwak.build.v1.ScanFeatureStateRequestH\x00\x42\x06\n\x04type\"\x1f\n\x1dScanSoftwareComponentsRequest\"\x1c\n\x1aScanVulnerabilitiesRequest\"\x1e\n\x1cScanMaliciousPackagesRequest\"\x1d\n\x1bScanPolicyViolationsRequest\"\x13\n\x11ScanStatusRequest\"/\n\x17ScanFeatureStateRequest\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t*\xad\x02\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\t\x12\x13\n\x0f\x42UILD_REQUESTED\x10\n\x12\x11\n\rBUILD_PENDING\x10\x0b\x12\x1b\n\x17\x46\x41ILED_INITIATING_BUILD\x10\x0c*\xa0\x02\n\x12MetricOperatorType\x12 \n\x1cMETRIC_OPERATOR_TYPE_INVALID\x10\x00\x12\x1f\n\x1bMETRIC_OPERATOR_TYPE_EQUALS\x10\x01\x12#\n\x1fMETRIC_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x12\"\n\x1eMETRIC_OPERATOR_TYPE_LESS_THAN\x10\x03\x12)\n%METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS\x10\x04\x12%\n!METRIC_OPERATOR_TYPE_GREATER_THAN\x10\x05\x12,\n(METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS\x10\x06*\x88\x01\n\x15ParameterOperatorType\x12#\n\x1fPARAMETER_OPERATOR_TYPE_INVALID\x10\x00\x12\"\n\x1ePARAMETER_OPERATOR_TYPE_EQUALS\x10\x01\x12&\n\"PARAMETER_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x42!\n\x11\x63om.qwak.build.v1B\nBuildProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.build.v1.build_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.qwak.build.v1B\nBuildProtoP\001'
  _BUILD_PARAMSENTRY._options = None
  _BUILD_PARAMSENTRY._serialized_options = b'8\001'
  _BUILD_METRICSENTRY._options = None
  _BUILD_METRICSENTRY._serialized_options = b'8\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _globals['_BUILDSTATUS']._serialized_start=7060
  _globals['_BUILDSTATUS']._serialized_end=7361
  _globals['_METRICOPERATORTYPE']._serialized_start=7364
  _globals['_METRICOPERATORTYPE']._serialized_end=7652
  _globals['_PARAMETEROPERATORTYPE']._serialized_start=7655
  _globals['_PARAMETEROPERATORTYPE']._serialized_end=7791
  _globals['_MODELSCHEMA']._serialized_start=107
  _globals['_MODELSCHEMA']._serialized_end=325
  _globals['_ENTITY']._serialized_start=327
  _globals['_ENTITY']._serialized_end=393
  _globals['_FEATURE']._serialized_start=396
  _globals['_FEATURE']._serialized_end=948
  _globals['_ONTHEFLYFEATURE']._serialized_start=951
  _globals['_ONTHEFLYFEATURE']._serialized_end=1084
  _globals['_BATCHFEATUREV1']._serialized_start=1086
  _globals['_BATCHFEATUREV1']._serialized_end=1159
  _globals['_STREAMINGFEATUREV1']._serialized_start=1161
  _globals['_STREAMINGFEATUREV1']._serialized_end=1238
  _globals['_BATCHFEATURE']._serialized_start=1240
  _globals['_BATCHFEATURE']._serialized_end=1311
  _globals['_STREAMINGFEATURE']._serialized_start=1313
  _globals['_STREAMINGFEATURE']._serialized_end=1388
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=1390
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=1476
  _globals['_EXPLICITFEATURE']._serialized_start=1478
  _globals['_EXPLICITFEATURE']._serialized_end=1553
  _globals['_REQUESTINPUT']._serialized_start=1555
  _globals['_REQUESTINPUT']._serialized_end=1627
  _globals['_SOURCEFEATURE']._serialized_start=1630
  _globals['_SOURCEFEATURE']._serialized_end=1775
  _globals['_PREDICTION']._serialized_start=1777
  _globals['_PREDICTION']._serialized_end=1847
  _globals['_INFERENCEOUTPUT']._serialized_start=1849
  _globals['_INFERENCEOUTPUT']._serialized_end=1924
  _globals['_VALUETYPE']._serialized_start=1927
  _globals['_VALUETYPE']._serialized_end=2088
  _globals['_VALUETYPE_TYPES']._serialized_start=1990
  _globals['_VALUETYPE_TYPES']._serialized_end=2088
  _globals['_PARAMETERCATEGORY']._serialized_start=2090
  _globals['_PARAMETERCATEGORY']._serialized_end=2196
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_start=2111
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_end=2196
  _globals['_BUILD']._serialized_start=2199
  _globals['_BUILD']._serialized_end=3123
  _globals['_BUILD_PARAMSENTRY']._serialized_start=3030
  _globals['_BUILD_PARAMSENTRY']._serialized_end=3075
  _globals['_BUILD_METRICSENTRY']._serialized_start=3077
  _globals['_BUILD_METRICSENTRY']._serialized_end=3123
  _globals['_AUDIT']._serialized_start=3126
  _globals['_AUDIT']._serialized_end=3281
  _globals['_BUILDCONFIGURATION']._serialized_start=3284
  _globals['_BUILDCONFIGURATION']._serialized_end=3591
  _globals['_BUILDPROPERTIES']._serialized_start=3594
  _globals['_BUILDPROPERTIES']._serialized_end=3780
  _globals['_BUILDMODELURI']._serialized_start=3782
  _globals['_BUILDMODELURI']._serialized_end=3885
  _globals['_BUILDENVIRONMENT']._serialized_start=3888
  _globals['_BUILDENVIRONMENT']._serialized_end=4100
  _globals['_DOCKERBUILD']._serialized_start=4103
  _globals['_DOCKERBUILD']._serialized_end=4405
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_start=4357
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_end=4405
  _globals['_LOCALBUILD']._serialized_start=4407
  _globals['_LOCALBUILD']._serialized_end=4457
  _globals['_PYTHONBUILD']._serialized_start=4460
  _globals['_PYTHONBUILD']._serialized_end=4728
  _globals['_CONDABUILD']._serialized_start=4730
  _globals['_CONDABUILD']._serialized_end=4762
  _globals['_POETRYBUILD']._serialized_start=4764
  _globals['_POETRYBUILD']._serialized_end=4820
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_start=4822
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_end=4897
  _globals['_REMOTEBUILD']._serialized_start=4899
  _globals['_REMOTEBUILD']._serialized_end=4991
  _globals['_REMOTEBUILDRESOURCES']._serialized_start=4994
  _globals['_REMOTEBUILDRESOURCES']._serialized_end=5137
  _globals['_STEP']._serialized_start=5139
  _globals['_STEP']._serialized_end=5234
  _globals['_BUILDFILTER']._serialized_start=5237
  _globals['_BUILDFILTER']._serialized_end=5484
  _globals['_METRICFILTER']._serialized_start=5486
  _globals['_METRICFILTER']._serialized_end=5600
  _globals['_PARAMETERFILTER']._serialized_start=5602
  _globals['_PARAMETERFILTER']._serialized_end=5728
  _globals['_FRAMEWORKMODELSSPEC']._serialized_start=5730
  _globals['_FRAMEWORKMODELSSPEC']._serialized_end=5830
  _globals['_FRAMEWORKMODEL']._serialized_start=5832
  _globals['_FRAMEWORKMODEL']._serialized_end=5931
  _globals['_HUGGINGFACEMODELSPEC']._serialized_start=5933
  _globals['_HUGGINGFACEMODELSPEC']._serialized_end=6026
  _globals['_SCANRESULTSUMMARY']._serialized_start=6028
  _globals['_SCANRESULTSUMMARY']._serialized_end=6142
  _globals['_ISSUE']._serialized_start=6144
  _globals['_ISSUE']._serialized_end=6241
  _globals['_BUILDIMAGEDETAILS']._serialized_start=6243
  _globals['_BUILDIMAGEDETAILS']._serialized_end=6319
  _globals['_SCANREQUESTTYPE']._serialized_start=6322
  _globals['_SCANREQUESTTYPE']._serialized_end=6861
  _globals['_SCANSOFTWARECOMPONENTSREQUEST']._serialized_start=6863
  _globals['_SCANSOFTWARECOMPONENTSREQUEST']._serialized_end=6894
  _globals['_SCANVULNERABILITIESREQUEST']._serialized_start=6896
  _globals['_SCANVULNERABILITIESREQUEST']._serialized_end=6924
  _globals['_SCANMALICIOUSPACKAGESREQUEST']._serialized_start=6926
  _globals['_SCANMALICIOUSPACKAGESREQUEST']._serialized_end=6956
  _globals['_SCANPOLICYVIOLATIONSREQUEST']._serialized_start=6958
  _globals['_SCANPOLICYVIOLATIONSREQUEST']._serialized_end=6987
  _globals['_SCANSTATUSREQUEST']._serialized_start=6989
  _globals['_SCANSTATUSREQUEST']._serialized_end=7008
  _globals['_SCANFEATURESTATEREQUEST']._serialized_start=7010
  _globals['_SCANFEATURESTATEREQUEST']._serialized_end=7057
# @@protoc_insertion_point(module_scope)
