"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OAuthTokenCredential(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    token: builtins.str
    """The token to use for authentication"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration timestamp of the credentials"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at", "token", b"token"]) -> None: ...

global___OAuthTokenCredential = OAuthTokenCredential
