# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_membership.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.users import user_pb2 as qwak_dot_administration_dot_v0_dot_users_dot_user__pb2
from _qwak_proto.qwak.self_service.account.v0 import managing_account_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/self_service/account/v0/account_membership.proto\x12\x1cqwak.self_service.account.v0\x1a\'qwak/administration/v0/users/user.proto\x1a\x33qwak/self_service/account/v0/managing_account.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"]\n\rInviteOptions\x12L\n\x0finvitation_spec\x18\x01 \x01(\x0b\x32\x33.qwak.self_service.account.v0.JoiningInvitationSpec\"\xa9\x02\n\x1cJoiningInvitationDescription\x12I\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.qwak.self_service.account.v0.JoiningInvitationMetadata\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32\x33.qwak.self_service.account.v0.JoiningInvitationSpec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\x35.qwak.self_service.account.v0.JoiningInvitationStatus\x12\x1e\n\x16num_of_account_members\x18\x04 \x01(\x05\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x05 \x01(\t\"\xa6\x01\n\x19JoiningInvitationMetadata\x12\x15\n\rinvitation_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpired_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ninvited_by\x18\x04 \x01(\t\"\x98\x03\n\x15JoiningInvitationSpec\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x17\n\x0f\x65nvironment_ids\x18\x03 \x03(\t\x12\x19\n\x11\x65nvironment_names\x18\x04 \x03(\t\x12z\n\x1d\x65nvironment_id_to_description\x18\x05 \x03(\x0b\x32S.qwak.self_service.account.v0.JoiningInvitationSpec.EnvironmentIdToDescriptionEntry\x1aw\n\x1f\x45nvironmentIdToDescriptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.qwak.self_service.account.v0.EnvironmentDescription:\x02\x38\x01\"\x97\x01\n\x17JoiningInvitationStatus\x12G\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x39.qwak.self_service.account.v0.JoiningInvitationStatusCode\x12\x33\n\x0flast_changed_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9c\x03\n\x16UserAccountDescription\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x1a\n\x12is_default_account\x18\x08 \x01(\x08\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x19\n\x11\x65nvironment_names\x18\x03 \x03(\t\x12{\n\x1d\x65nvironment_id_to_description\x18\x04 \x03(\x0b\x32T.qwak.self_service.account.v0.UserAccountDescription.EnvironmentIdToDescriptionEntry\x1aw\n\x1f\x45nvironmentIdToDescriptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.qwak.self_service.account.v0.EnvironmentDescription:\x02\x38\x01\"w\n\x16\x45nvironmentDescription\x12\x18\n\x10\x65nvironment_name\x18\x01 \x01(\t\x12\x43\n\x0e\x63loud_provider\x18\x02 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProvider*\x81\x01\n\x1bJoiningInvitationStatusCode\x12*\n&JOINING_INVITATION_STATUS_CODE_INVALID\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x0c\n\x08\x44\x45\x43LINED\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x42\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.self_service.account.v0.account_membership_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY._options = None
  _JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY._serialized_options = b'8\001'
  _USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY._options = None
  _USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY._serialized_options = b'8\001'
  _globals['_JOININGINVITATIONSTATUSCODE']._serialized_start=1880
  _globals['_JOININGINVITATIONSTATUSCODE']._serialized_end=2009
  _globals['_INVITEOPTIONS']._serialized_start=214
  _globals['_INVITEOPTIONS']._serialized_end=307
  _globals['_JOININGINVITATIONDESCRIPTION']._serialized_start=310
  _globals['_JOININGINVITATIONDESCRIPTION']._serialized_end=607
  _globals['_JOININGINVITATIONMETADATA']._serialized_start=610
  _globals['_JOININGINVITATIONMETADATA']._serialized_end=776
  _globals['_JOININGINVITATIONSPEC']._serialized_start=779
  _globals['_JOININGINVITATIONSPEC']._serialized_end=1187
  _globals['_JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_start=1068
  _globals['_JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_end=1187
  _globals['_JOININGINVITATIONSTATUS']._serialized_start=1190
  _globals['_JOININGINVITATIONSTATUS']._serialized_end=1341
  _globals['_USERACCOUNTDESCRIPTION']._serialized_start=1344
  _globals['_USERACCOUNTDESCRIPTION']._serialized_end=1756
  _globals['_USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_start=1068
  _globals['_USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_end=1187
  _globals['_ENVIRONMENTDESCRIPTION']._serialized_start=1758
  _globals['_ENVIRONMENTDESCRIPTION']._serialized_end=1877
# @@protoc_insertion_point(module_scope)
