# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/account_secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.secret.v0 import secret_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/admiral/secret/v0/account_secret.proto\x12\x16qwak.admiral.secret.v0\x1a#qwak/admiral/secret/v0/secret.proto\x1a\x1cgoogle/protobuf/struct.proto\"H\n\x1d\x41\x63\x63ountSystemSecretIdentifier\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\"^\n\x1d\x41\x63\x63ountSystemSecretDefinition\x12=\n\x04spec\x18\x01 \x01(\x0b\x32/.qwak.admiral.secret.v0.AccountSystemSecretSpec\"\xb5\x01\n\x17\x41\x63\x63ountSystemSecretSpec\x12Q\n\x12\x61\x63\x63ount_identifier\x18\x01 \x01(\x0b\x32\x35.qwak.admiral.secret.v0.AccountSystemSecretIdentifier\x12G\n\x15\x61\x63\x63ount_system_secret\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpecB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.secret.v0.account_secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _globals['_ACCOUNTSYSTEMSECRETIDENTIFIER']._serialized_start=138
  _globals['_ACCOUNTSYSTEMSECRETIDENTIFIER']._serialized_end=210
  _globals['_ACCOUNTSYSTEMSECRETDEFINITION']._serialized_start=212
  _globals['_ACCOUNTSYSTEMSECRETDEFINITION']._serialized_end=306
  _globals['_ACCOUNTSYSTEMSECRETSPEC']._serialized_start=309
  _globals['_ACCOUNTSYSTEMSECRETSPEC']._serialized_end=490
# @@protoc_insertion_point(module_scope)
