# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/jfrog/v0/token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/ecosystem/jfrog/v0/token.proto\x12\x1dqwak.ecosystem.jfrog.token.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\nJFrogToken\x12G\n\ndefinition\x18\x01 \x01(\x0b\x32\x33.qwak.ecosystem.jfrog.token.v0.JFrogTokenDefinition\x12N\n\x0etenant_details\x18\x02 \x01(\x0b\x32\x36.qwak.ecosystem.jfrog.token.v0.JFrogTokenTenantDetails\"/\n\x17JFrogTokenTenantDetails\x12\x14\n\x0cplatform_url\x18\x01 \x01(\t\"\xe4\x01\n\x14JFrogTokenDefinition\x12\r\n\x05token\x18\x01 \x01(\t\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x12\x35\n\x0f\x65xpiration_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x14\n\x0csubject_name\x18\x05 \x01(\t\x12\x10\n\x08token_id\x18\x06 \x01(\tB\x18\n\x16optional_refresh_tokenB\x1a\n\x18optional_expiration_time\"\x8c\x02\n\x0eJFrogTokenSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12V\n\x18subject_and_scope_source\x18\x02 \x01(\x0b\x32\x34.qwak.ecosystem.jfrog.token.v0.SubjectAndScopeSource\x12\x45\n\taudiences\x18\x03 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudiences\x12\x42\n\x08ttl_spec\x18\x04 \x01(\x0b\x32\x30.qwak.ecosystem.jfrog.token.v0.JFrogTokenTTLSpec\"\x89\x02\n\x1d\x41rtifactoryImagePullTokenSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x1a\n\x0erepository_key\x18\x02 \x01(\tB\x02\x18\x01\x12\x42\n\x08ttl_spec\x18\x03 \x01(\x0b\x32\x30.qwak.ecosystem.jfrog.token.v0.JFrogTokenTTLSpec\x12\x1b\n\x0frepository_keys\x18\x04 \x03(\tB\x02\x18\x01\x12R\n\x16repository_token_specs\x18\x05 \x03(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.RepositoryTokenSpec\"\x97\x01\n\x16PersistTokenClaimsSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x11\n\x05token\x18\x02 \x01(\tB\x02\x18\x01\x12Q\n\x15token_scope_extension\x18\x03 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.TokenScopeExtension\"m\n\x14JFrogTokenRevokeSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x0f\n\x05token\x18\x02 \x01(\tH\x00\x12\x12\n\x08token_id\x18\x03 \x01(\tH\x00\x42\x17\n\x15token_descriptor_type\"\xa8\x01\n\x13RepositoryTokenSpec\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.qwak.ecosystem.jfrog.token.v0.RepositoryType\x12G\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x32.qwak.ecosystem.jfrog.token.v0.JFrogPermissionType\"{\n\x11JFrogTokenTTLSpec\x12\x35\n\x0f\x65xpiration_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x13\n\x0brefreshable\x18\x02 \x01(\x08\x42\x1a\n\x18optional_expiration_time\"\xf4\x01\n\x15SubjectAndScopeSource\x12\x13\n\x05token\x18\x01 \x01(\tB\x02\x18\x01H\x00\x12\x12\n\x08token_id\x18\x02 \x01(\tH\x00\x12S\n\x11subject_and_scope\x18\x03 \x01(\x0b\x32\x36.qwak.ecosystem.jfrog.token.v0.ExplicitSubjectAndScopeH\x00\x12S\n\x15token_scope_extension\x18\x04 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.TokenScopeExtensionH\x00\x42\x08\n\x06source\"P\n\x17\x45xplicitSubjectAndScope\x12\x11\n\x07subject\x18\x01 \x01(\tH\x00\x12\x0e\n\x06scopes\x18\x02 \x01(\tB\x12\n\x10optional_subject\"[\n\x13JFrogTokenAudiences\x12\x44\n\taudiences\x18\x01 \x03(\x0b\x32\x31.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudience\"\x86\x02\n\x12JFrogTokenAudience\x12L\n\x08jfrog_ml\x18\x01 \x01(\x0b\x32\x38.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceJFrogMLH\x00\x12S\n\x0b\x61rtifactory\x18\x02 \x01(\x0b\x32<.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceArtifactoryH\x00\x12\x45\n\x04xray\x18\x03 \x01(\x0b\x32\x35.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceXRayH\x00\x42\x06\n\x04type\"\x1f\n\x1dJFrogTokenAudienceArtifactory\"\x18\n\x16JFrogTokenAudienceXRay\"\x1b\n\x19JFrogTokenAudienceJFrogML\"?\n\x13TokenScopeExtension\x12\r\n\x05token\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64\x64itional_scopes\x18\x02 \x03(\t*H\n\x0eRepositoryType\x12\x1f\n\x1bREPOSITORY_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\n\n\x06REMOTE\x10\x02*\x8e\x01\n\x13JFrogPermissionType\x12%\n!JFROG_PERMISSION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\x0c\n\x08\x41NNOTATE\x10\x04\x12\x0b\n\x07\x45XECUTE\x10\x05\x12\x08\n\x04SCAN\x10\x06\x12\n\n\x06MANAGE\x10\x07\x42\xb7\x01\n\x1a\x63om.qwak.ai.jfrog.token.v0P\x01Z\x96\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.jfrog.v0.token_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.jfrog.token.v0P\001Z\226\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0'
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_key']._options = None
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_key']._serialized_options = b'\030\001'
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_keys']._options = None
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_keys']._serialized_options = b'\030\001'
  _PERSISTTOKENCLAIMSSPEC.fields_by_name['token']._options = None
  _PERSISTTOKENCLAIMSSPEC.fields_by_name['token']._serialized_options = b'\030\001'
  _SUBJECTANDSCOPESOURCE.fields_by_name['token']._options = None
  _SUBJECTANDSCOPESOURCE.fields_by_name['token']._serialized_options = b'\030\001'
  _globals['_REPOSITORYTYPE']._serialized_start=2491
  _globals['_REPOSITORYTYPE']._serialized_end=2563
  _globals['_JFROGPERMISSIONTYPE']._serialized_start=2566
  _globals['_JFROGPERMISSIONTYPE']._serialized_end=2708
  _globals['_JFROGTOKEN']._serialized_start=104
  _globals['_JFROGTOKEN']._serialized_end=269
  _globals['_JFROGTOKENTENANTDETAILS']._serialized_start=271
  _globals['_JFROGTOKENTENANTDETAILS']._serialized_end=318
  _globals['_JFROGTOKENDEFINITION']._serialized_start=321
  _globals['_JFROGTOKENDEFINITION']._serialized_end=549
  _globals['_JFROGTOKENSPEC']._serialized_start=552
  _globals['_JFROGTOKENSPEC']._serialized_end=820
  _globals['_ARTIFACTORYIMAGEPULLTOKENSPEC']._serialized_start=823
  _globals['_ARTIFACTORYIMAGEPULLTOKENSPEC']._serialized_end=1088
  _globals['_PERSISTTOKENCLAIMSSPEC']._serialized_start=1091
  _globals['_PERSISTTOKENCLAIMSSPEC']._serialized_end=1242
  _globals['_JFROGTOKENREVOKESPEC']._serialized_start=1244
  _globals['_JFROGTOKENREVOKESPEC']._serialized_end=1353
  _globals['_REPOSITORYTOKENSPEC']._serialized_start=1356
  _globals['_REPOSITORYTOKENSPEC']._serialized_end=1524
  _globals['_JFROGTOKENTTLSPEC']._serialized_start=1526
  _globals['_JFROGTOKENTTLSPEC']._serialized_end=1649
  _globals['_SUBJECTANDSCOPESOURCE']._serialized_start=1652
  _globals['_SUBJECTANDSCOPESOURCE']._serialized_end=1896
  _globals['_EXPLICITSUBJECTANDSCOPE']._serialized_start=1898
  _globals['_EXPLICITSUBJECTANDSCOPE']._serialized_end=1978
  _globals['_JFROGTOKENAUDIENCES']._serialized_start=1980
  _globals['_JFROGTOKENAUDIENCES']._serialized_end=2071
  _globals['_JFROGTOKENAUDIENCE']._serialized_start=2074
  _globals['_JFROGTOKENAUDIENCE']._serialized_end=2336
  _globals['_JFROGTOKENAUDIENCEARTIFACTORY']._serialized_start=2338
  _globals['_JFROGTOKENAUDIENCEARTIFACTORY']._serialized_end=2369
  _globals['_JFROGTOKENAUDIENCEXRAY']._serialized_start=2371
  _globals['_JFROGTOKENAUDIENCEXRAY']._serialized_end=2395
  _globals['_JFROGTOKENAUDIENCEJFROGML']._serialized_start=2397
  _globals['_JFROGTOKENAUDIENCEJFROGML']._serialized_end=2424
  _globals['_TOKENSCOPEEXTENSION']._serialized_start=2426
  _globals['_TOKENSCOPEEXTENSION']._serialized_end=2489
# @@protoc_insertion_point(module_scope)
