# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.v0.environments import environment_service_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2


class EnvironmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnvironment = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/CreateEnvironment',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/GetEnvironment',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.FromString,
                )
        self.UpdateEnvironmentConfiguration = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentConfiguration',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.FromString,
                )
        self.UpdateEnvironmentPersonalization = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentPersonalization',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.FromString,
                )
        self.ListEnvironments = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/ListEnvironments',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.FromString,
                )
        self.GetEnvironmentApplicationUserCredentials = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/GetEnvironmentApplicationUserCredentials',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.FromString,
                )
        self.SetEnvironmentApplicationUserCredentials = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/SetEnvironmentApplicationUserCredentials',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.FromString,
                )


class EnvironmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEnvironment(self, request, context):
        """Create a environment in Qwak system
        The operation initiates of process of environment creation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """Get an environment information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentConfiguration(self, request, context):
        """Update a configuration of an environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentPersonalization(self, request, context):
        """Update a personalization of an environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """List all Environments registered to Qwak
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentApplicationUserCredentials(self, request, context):
        """Get qwak credentials for environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEnvironmentApplicationUserCredentials(self, request, context):
        """Get qwak credentials for environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EnvironmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.SerializeToString,
            ),
            'UpdateEnvironmentConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentConfiguration,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.SerializeToString,
            ),
            'UpdateEnvironmentPersonalization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentPersonalization,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'GetEnvironmentApplicationUserCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentApplicationUserCredentials,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.SerializeToString,
            ),
            'SetEnvironmentApplicationUserCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnvironmentApplicationUserCredentials,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.environment.EnvironmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EnvironmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/CreateEnvironment',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/GetEnvironment',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentConfiguration',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentPersonalization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentPersonalization',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/ListEnvironments',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentApplicationUserCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/GetEnvironmentApplicationUserCredentials',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEnvironmentApplicationUserCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/SetEnvironmentApplicationUserCredentials',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
