# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.integration import open_a_i_integration_pb2 as qwak_dot_integration_dot_open__a__i__integration__pb2
from _qwak_proto.qwak.integration import opsgenie_integration_pb2 as qwak_dot_integration_dot_opsgenie__integration__pb2
from _qwak_proto.qwak.integration import pagerduty_integration_pb2 as qwak_dot_integration_dot_pagerduty__integration__pb2
from _qwak_proto.qwak.integration import slack_app_integration_pb2 as qwak_dot_integration_dot_slack__app__integration__pb2
from _qwak_proto.qwak.integration import hugging_face_integration_pb2 as qwak_dot_integration_dot_hugging__face__integration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/integration/integration.proto\x12\x1bqwak.integration.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+qwak/integration/open_a_i_integration.proto\x1a+qwak/integration/opsgenie_integration.proto\x1a,qwak/integration/pagerduty_integration.proto\x1a,qwak/integration/slack_app_integration.proto\x1a/qwak/integration/hugging_face_integration.proto\"\xac\x04\n\x0bIntegration\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12J\n\x11jfrog_integration\x18\x02 \x01(\x0b\x32-.qwak.integration.management.JFrogIntegrationH\x00\x12P\n\x14opsgenie_integration\x18\x03 \x01(\x0b\x32\x30.qwak.integration.management.OpsgenieIntegrationH\x00\x12R\n\x15pagerduty_integration\x18\x04 \x01(\x0b\x32\x31.qwak.integration.management.PagerdutyIntegrationH\x00\x12V\n\x1aqwak_slack_app_integration\x18\x05 \x01(\x0b\x32\x30.qwak.integration.management.SlackAppIntegrationH\x00\x12L\n\x12openai_integration\x18\x07 \x01(\x0b\x32..qwak.integration.management.OpenAIIntegrationH\x00\x12W\n\x18hugging_face_integration\x18\x08 \x01(\x0b\x32\x33.qwak.integration.management.HuggingFaceIntegrationH\x00\x12\x0c\n\x04name\x18\x06 \x01(\tB\x06\n\x04type\"\xce\x04\n\x0fIntegrationSpec\x12S\n\x16jfrog_integration_spec\x18\x01 \x01(\x0b\x32\x31.qwak.integration.management.JFrogIntegrationSpecH\x00\x12Y\n\x19opsgenie_integration_spec\x18\x02 \x01(\x0b\x32\x34.qwak.integration.management.OpsgenieIntegrationSpecH\x00\x12[\n\x1apagerduty_integration_spec\x18\x03 \x01(\x0b\x32\x35.qwak.integration.management.PagerdutyIntegrationSpecH\x00\x12_\n\x1fqwak_slack_app_integration_spec\x18\x04 \x01(\x0b\x32\x34.qwak.integration.management.SlackAppIntegrationSpecH\x00\x12U\n\x17openai_integration_spec\x18\x06 \x01(\x0b\x32\x32.qwak.integration.management.OpenAIIntegrationSpecH\x00\x12`\n\x1dhugging_face_integration_spec\x18\x07 \x01(\x0b\x32\x37.qwak.integration.management.HuggingFaceIntegrationSpecH\x00\x12\x0c\n\x04name\x18\x05 \x01(\tB\x06\n\x04spec\"V\n\x10JFrogIntegration\x12\x42\n\x0ejfrog_settings\x18\x01 \x01(\x0b\x32*.qwak.integration.management.JFrogSettings\"o\n\x14JFrogIntegrationSpec\x12\x13\n\x0b\x61\x64min_token\x18\x01 \x01(\t\x12\x42\n\x0ejfrog_settings\x18\x02 \x01(\x0b\x32*.qwak.integration.management.JFrogSettings\"\xb3\x01\n\rJFrogSettings\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x1b\n\x13python_repositories\x18\x02 \x03(\t\x12\x1e\n\x16huggingface_repository\x18\x03 \x01(\t\x12%\n\x1d\x61llow_additional_repositories\x18\x04 \x01(\x08\x12,\n$create_huggingface_remote_repository\x18\x05 \x01(\x08\"\xbe\x04\n\x19IntegrationValidationSpec\x12Q\n\x15jfrog_validation_spec\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.JFrogValidationSpecH\x00\x12W\n\x18opsgenie_validation_spec\x18\x02 \x01(\x0b\x32\x33.qwak.integration.management.OpsgenieValidationSpecH\x00\x12Y\n\x19pagerduty_validation_spec\x18\x03 \x01(\x0b\x32\x34.qwak.integration.management.PagerdutyValidationSpecH\x00\x12]\n\x1eqwak_slack_app_validation_spec\x18\x04 \x01(\x0b\x32\x33.qwak.integration.management.SlackAppValidationSpecH\x00\x12S\n\x16openai_validation_spec\x18\x05 \x01(\x0b\x32\x31.qwak.integration.management.OpenAIValidationSpecH\x00\x12^\n\x1chugging_face_validation_spec\x18\x06 \x01(\x0b\x32\x36.qwak.integration.management.HuggingFaceValidationSpecH\x00\x42\x06\n\x04type\"<\n\x13JFrogValidationSpec\x12\x13\n\x0b\x61\x64min_token\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\"\xe7\x04\n\x12IntegrationOptions\x12Y\n\x19jfrog_integration_options\x18\x01 \x01(\x0b\x32\x34.qwak.integration.management.JFrogIntegrationOptionsH\x00\x12_\n\x1copsgenie_integration_options\x18\x02 \x01(\x0b\x32\x37.qwak.integration.management.OpsgenieIntegrationOptionsH\x00\x12\x61\n\x1dpagerduty_integration_options\x18\x03 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyIntegrationOptionsH\x00\x12\x65\n\"qwak_slack_app_integration_options\x18\x04 \x01(\x0b\x32\x37.qwak.integration.management.SlackAppIntegrationOptionsH\x00\x12[\n\x1aopenai_integration_options\x18\x05 \x01(\x0b\x32\x35.qwak.integration.management.OpenAIIntegrationOptionsH\x00\x12\x66\n hugging_face_integration_options\x18\x06 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceIntegrationOptionsH\x00\x42\x06\n\x04type\"\xd8\x01\n\x17JFrogIntegrationOptions\x12[\n%available_private_python_repositories\x18\x01 \x03(\x0b\x32,.qwak.integration.management.JfrogRepository\x12`\n*available_private_huggingface_repositories\x18\x02 \x03(\x0b\x32,.qwak.integration.management.JfrogRepository\"\x1f\n\x0fJfrogRepository\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x8d\x01\n\x1bValidationIntegrationResult\x12\x15\n\ris_successful\x18\x01 \x01(\x08\x12@\n\x07options\x18\x02 \x01(\x0b\x32/.qwak.integration.management.IntegrationOptions\x12\x15\n\rerror_message\x18\x03 \x01(\t*\xef\x01\n\x0fIntegrationType\x12\x1c\n\x18INTEGRATION_TYPE_INVALID\x10\x00\x12\x1a\n\x16INTEGRATION_TYPE_JFROG\x10\x01\x12\x1d\n\x19INTEGRATION_TYPE_OPSGENIE\x10\x02\x12\x1e\n\x1aINTEGRATION_TYPE_PAGERDUTY\x10\x03\x12#\n\x1fINTEGRATION_TYPE_QWAK_SLACK_APP\x10\x04\x12\x1b\n\x17INTEGRATION_TYPE_OPENAI\x10\x05\x12!\n\x1dINTEGRATION_TYPE_HUGGING_FACE\x10\x06\x42H\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_INTEGRATIONTYPE']._serialized_start=3520
  _globals['_INTEGRATIONTYPE']._serialized_end=3759
  _globals['_INTEGRATION']._serialized_start=332
  _globals['_INTEGRATION']._serialized_end=888
  _globals['_INTEGRATIONSPEC']._serialized_start=891
  _globals['_INTEGRATIONSPEC']._serialized_end=1481
  _globals['_JFROGINTEGRATION']._serialized_start=1483
  _globals['_JFROGINTEGRATION']._serialized_end=1569
  _globals['_JFROGINTEGRATIONSPEC']._serialized_start=1571
  _globals['_JFROGINTEGRATIONSPEC']._serialized_end=1682
  _globals['_JFROGSETTINGS']._serialized_start=1685
  _globals['_JFROGSETTINGS']._serialized_end=1864
  _globals['_INTEGRATIONVALIDATIONSPEC']._serialized_start=1867
  _globals['_INTEGRATIONVALIDATIONSPEC']._serialized_end=2441
  _globals['_JFROGVALIDATIONSPEC']._serialized_start=2443
  _globals['_JFROGVALIDATIONSPEC']._serialized_end=2503
  _globals['_INTEGRATIONOPTIONS']._serialized_start=2506
  _globals['_INTEGRATIONOPTIONS']._serialized_end=3121
  _globals['_JFROGINTEGRATIONOPTIONS']._serialized_start=3124
  _globals['_JFROGINTEGRATIONOPTIONS']._serialized_end=3340
  _globals['_JFROGREPOSITORY']._serialized_start=3342
  _globals['_JFROGREPOSITORY']._serialized_end=3373
  _globals['_VALIDATIONINTEGRATIONRESULT']._serialized_start=3376
  _globals['_VALIDATIONINTEGRATIONRESULT']._serialized_end=3517
# @@protoc_insertion_point(module_scope)
