"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HuggingFaceIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_SYSTEM_SECRET_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_system_secret_descriptor(self) -> global___HuggingFaceApiTokenSystemSecretDescriptor: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_system_secret_descriptor: global___HuggingFaceApiTokenSystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_system_secret_descriptor", b"hugging_face_api_token_system_secret_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_system_secret_descriptor", b"hugging_face_api_token_system_secret_descriptor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_system_secret_descriptor"] | None: ...

global___HuggingFaceIntegration = HuggingFaceIntegration

class HuggingFaceIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_auth_config(self) -> global___HuggingFaceApiTokenAuthConfig: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_auth_config: global___HuggingFaceApiTokenAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_auth_config"] | None: ...

global___HuggingFaceIntegrationSpec = HuggingFaceIntegrationSpec

class HuggingFaceValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_auth_config(self) -> global___HuggingFaceApiTokenAuthConfig: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_auth_config: global___HuggingFaceApiTokenAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_auth_config"] | None: ...

global___HuggingFaceValidationSpec = HuggingFaceValidationSpec

class HuggingFaceApiTokenAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_TOKEN_FIELD_NUMBER: builtins.int
    api_token: builtins.str
    def __init__(
        self,
        *,
        api_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token"]) -> None: ...

global___HuggingFaceApiTokenAuthConfig = HuggingFaceApiTokenAuthConfig

class HuggingFaceApiTokenSystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    API_TOKEN_SECRET_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    api_token_secret_key: builtins.str
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        api_token_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token_secret_key", b"api_token_secret_key", "secret_name", b"secret_name"]) -> None: ...

global___HuggingFaceApiTokenSystemSecretDescriptor = HuggingFaceApiTokenSystemSecretDescriptor

class HuggingFaceIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HuggingFaceIntegrationOptions = HuggingFaceIntegrationOptions
