"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.v0.environments.environment_pb2
import qwak.administration.v1.environments.environment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    environment_name: builtins.str
    """Environment name"""
    cluster_id: builtins.str
    """The JFrogML Cluster the environment is deployed in."""
    @property
    def spec(self) -> qwak.administration.v1.environments.environment_pb2.EnvironmentRuntimeConfigSpec:
        """Environment configuration"""
    def __init__(
        self,
        *,
        environment_name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        spec: qwak.administration.v1.environments.environment_pb2.EnvironmentRuntimeConfigSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "environment_name", b"environment_name", "spec", b"spec"]) -> None: ...

global___CreateEnvironmentRequest = CreateEnvironmentRequest

class CreateEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Created environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___CreateEnvironmentResponse = CreateEnvironmentResponse
