"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogsStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELASTICSEARCH_FIELD_NUMBER: builtins.int
    @property
    def elasticsearch(self) -> qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2.ElasticsearchConfiguration: ...
    def __init__(
        self,
        *,
        elasticsearch: qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2.ElasticsearchConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elasticsearch", b"elasticsearch", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elasticsearch", b"elasticsearch", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["elasticsearch"] | None: ...

global___LogsStorageConfiguration = LogsStorageConfiguration
