# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/feature_store/entities/entity.proto\x12\x1bqwak.feature.store.entities\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x01\n\x06\x45ntity\x12H\n\x11\x65ntity_definition\x18\x01 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12=\n\x08metadata\x18\x02 \x01(\x0b\x32+.qwak.feature.store.entities.EntityMetadata\x12\x42\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32,.qwak.feature.store.entities.FeatureSetBrief\"c\n\x10\x45ntityDefinition\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"\xa4\x01\n\x0e\x45ntityMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb3\x01\n\nEntitySpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x45\n\nvalue_type\x18\x04 \x01(\x0e\x32\x31.qwak.feature.store.entities.EntitySpec.ValueType\"-\n\tValueType\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x07\n\x03INT\x10\x02\"C\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\tB[\n&com.qwak.ai.feature.store.entities.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.entities.entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.entities.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _globals['_ENTITY']._serialized_start=107
  _globals['_ENTITY']._serialized_end=320
  _globals['_ENTITYDEFINITION']._serialized_start=322
  _globals['_ENTITYDEFINITION']._serialized_end=421
  _globals['_ENTITYMETADATA']._serialized_start=424
  _globals['_ENTITYMETADATA']._serialized_end=588
  _globals['_ENTITYSPEC']._serialized_start=591
  _globals['_ENTITYSPEC']._serialized_end=770
  _globals['_ENTITYSPEC_VALUETYPE']._serialized_start=725
  _globals['_ENTITYSPEC_VALUETYPE']._serialized_end=770
  _globals['_FEATURESETBRIEF']._serialized_start=772
  _globals['_FEATURESETBRIEF']._serialized_end=839
# @@protoc_insertion_point(module_scope)
