# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/feature_store/sources/data_source_service.proto\x12\x1aqwak.feature.store.sources\x1a,qwak/feature_store/sources/data_source.proto\"_\n\x17\x43reateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18\x43reateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"w\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18UpdateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"1\n\x17\x44\x65leteDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"2\n\x18GetDataSourceByIdRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"X\n\x19GetDataSourceByIdResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"6\n\x1aGetDataSourceByNameRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\"Z\n\x1bGetDataSourceByNameResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"\x18\n\x16ListDataSourcesRequest\"W\n\x17ListDataSourcesResponse\x12<\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32&.qwak.feature.store.sources.DataSource\"!\n\x1fListDataSourcesByAccountRequest\"`\n ListDataSourcesByAccountResponse\x12<\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32&.qwak.feature.store.sources.DataSource\"Q\n CreateDataSourceUploadURLRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\x12\x13\n\x0bobject_name\x18\x02 \x01(\t\"7\n!CreateDataSourceUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t2\xed\t\n\x11\x44\x61taSourceService\x12}\n\x10\x43reateDataSource\x12\x33.qwak.feature.store.sources.CreateDataSourceRequest\x1a\x34.qwak.feature.store.sources.CreateDataSourceResponse\x12}\n\x10UpdateDataSource\x12\x33.qwak.feature.store.sources.UpdateDataSourceRequest\x1a\x34.qwak.feature.store.sources.UpdateDataSourceResponse\x12}\n\x10\x44\x65leteDataSource\x12\x33.qwak.feature.store.sources.DeleteDataSourceRequest\x1a\x34.qwak.feature.store.sources.DeleteDataSourceResponse\x12\x80\x01\n\x11GetDataSourceById\x12\x34.qwak.feature.store.sources.GetDataSourceByIdRequest\x1a\x35.qwak.feature.store.sources.GetDataSourceByIdResponse\x12\x86\x01\n\x13GetDataSourceByName\x12\x36.qwak.feature.store.sources.GetDataSourceByNameRequest\x1a\x37.qwak.feature.store.sources.GetDataSourceByNameResponse\x12z\n\x0fListDataSources\x12\x32.qwak.feature.store.sources.ListDataSourcesRequest\x1a\x33.qwak.feature.store.sources.ListDataSourcesResponse\x12\x95\x01\n\x18ListDataSourcesByAccount\x12;.qwak.feature.store.sources.ListDataSourcesByAccountRequest\x1a<.qwak.feature.store.sources.ListDataSourcesByAccountResponse\x12\x9d\x01\n\x19\x43reateDataSourceUploadURL\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1b\x43reateDataSourceUploadURLV1\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponseB[\n(com.qwak.ai.feature.store.management.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._options = None
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._serialized_options = b'\210\002\001'
  _globals['_CREATEDATASOURCEREQUEST']._serialized_start=130
  _globals['_CREATEDATASOURCEREQUEST']._serialized_end=225
  _globals['_CREATEDATASOURCERESPONSE']._serialized_start=227
  _globals['_CREATEDATASOURCERESPONSE']._serialized_end=314
  _globals['_UPDATEDATASOURCEREQUEST']._serialized_start=316
  _globals['_UPDATEDATASOURCEREQUEST']._serialized_end=435
  _globals['_UPDATEDATASOURCERESPONSE']._serialized_start=437
  _globals['_UPDATEDATASOURCERESPONSE']._serialized_end=524
  _globals['_DELETEDATASOURCEREQUEST']._serialized_start=526
  _globals['_DELETEDATASOURCEREQUEST']._serialized_end=575
  _globals['_DELETEDATASOURCERESPONSE']._serialized_start=577
  _globals['_DELETEDATASOURCERESPONSE']._serialized_end=603
  _globals['_GETDATASOURCEBYIDREQUEST']._serialized_start=605
  _globals['_GETDATASOURCEBYIDREQUEST']._serialized_end=655
  _globals['_GETDATASOURCEBYIDRESPONSE']._serialized_start=657
  _globals['_GETDATASOURCEBYIDRESPONSE']._serialized_end=745
  _globals['_GETDATASOURCEBYNAMEREQUEST']._serialized_start=747
  _globals['_GETDATASOURCEBYNAMEREQUEST']._serialized_end=801
  _globals['_GETDATASOURCEBYNAMERESPONSE']._serialized_start=803
  _globals['_GETDATASOURCEBYNAMERESPONSE']._serialized_end=893
  _globals['_LISTDATASOURCESREQUEST']._serialized_start=895
  _globals['_LISTDATASOURCESREQUEST']._serialized_end=919
  _globals['_LISTDATASOURCESRESPONSE']._serialized_start=921
  _globals['_LISTDATASOURCESRESPONSE']._serialized_end=1008
  _globals['_LISTDATASOURCESBYACCOUNTREQUEST']._serialized_start=1010
  _globals['_LISTDATASOURCESBYACCOUNTREQUEST']._serialized_end=1043
  _globals['_LISTDATASOURCESBYACCOUNTRESPONSE']._serialized_start=1045
  _globals['_LISTDATASOURCESBYACCOUNTRESPONSE']._serialized_end=1141
  _globals['_CREATEDATASOURCEUPLOADURLREQUEST']._serialized_start=1143
  _globals['_CREATEDATASOURCEUPLOADURLREQUEST']._serialized_end=1224
  _globals['_CREATEDATASOURCEUPLOADURLRESPONSE']._serialized_start=1226
  _globals['_CREATEDATASOURCEUPLOADURLRESPONSE']._serialized_end=1281
  _globals['_DATASOURCESERVICE']._serialized_start=1284
  _globals['_DATASOURCESERVICE']._serialized_end=2545
# @@protoc_insertion_point(module_scope)
