# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from jfml.hosting_gateway.v1 import hosting_gateway_service_pb2 as jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2


class HostingGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBuildVersioningUploadURL = channel.unary_unary(
                '/jfml.hosting_gateway.v1.HostingGatewayService/GetBuildVersioningUploadURL',
                request_serializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
                response_deserializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
                )


class HostingGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetBuildVersioningUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code or data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HostingGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBuildVersioningUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadURL,
                    request_deserializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.FromString,
                    response_serializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jfml.hosting_gateway.v1.HostingGatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HostingGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetBuildVersioningUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/jfml.hosting_gateway.v1.HostingGatewayService/GetBuildVersioningUploadURL',
            jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
            jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
