# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/azure_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.ecosystem.v0 import auth_pb2 as qwak_dot_ecosystem_dot_v0_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/ecosystem/v0/azure_credentials.proto\x12\x11qwak.ecosystem.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cqwak/ecosystem/v0/auth.proto\"\xb9\x02\n\x19\x41zureTemporaryCredentials\x12w\n.azure_databricks_service_temporary_credentials\x18\x01 \x01(\x0b\x32=.qwak.ecosystem.v0.AzureDatabricksServiceTemporaryCredentialsH\x00\x12J\n\x16\x64\x61tabricks_credentials\x18\x02 \x01(\x0b\x32(.qwak.ecosystem.v0.DatabricksCredentialsH\x00\x12O\n\x19\x61zure_storage_credentials\x18\x03 \x01(\x0b\x32*.qwak.ecosystem.v0.AzureStorageCredentialsH\x00\x42\x06\n\x04type\"\xc5\x01\n*AzureDatabricksServiceTemporaryCredentials\x12H\n\x16\x64\x61tabricks_credentials\x18\x01 \x01(\x0b\x32(.qwak.ecosystem.v0.DatabricksCredentials\x12M\n\x19\x61zure_storage_credentials\x18\x02 \x01(\x0b\x32*.qwak.ecosystem.v0.AzureStorageCredentials\"j\n\x15\x44\x61tabricksCredentials\x12I\n\x16oauth_token_credential\x18\x01 \x01(\x0b\x32\'.qwak.ecosystem.v0.OAuthTokenCredentialH\x00\x42\x06\n\x04type\"i\n\x17\x41zureStorageCredentials\x12\x46\n\x14sas_token_credential\x18\x01 \x01(\x0b\x32&.qwak.ecosystem.v0.SASTokenCredentialsH\x00\x42\x06\n\x04type\"T\n\x13SASTokenCredentials\x12\r\n\x05token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.v0.azure_credentials_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _globals['_AZURETEMPORARYCREDENTIALS']._serialized_start=128
  _globals['_AZURETEMPORARYCREDENTIALS']._serialized_end=441
  _globals['_AZUREDATABRICKSSERVICETEMPORARYCREDENTIALS']._serialized_start=444
  _globals['_AZUREDATABRICKSSERVICETEMPORARYCREDENTIALS']._serialized_end=641
  _globals['_DATABRICKSCREDENTIALS']._serialized_start=643
  _globals['_DATABRICKSCREDENTIALS']._serialized_end=749
  _globals['_AZURESTORAGECREDENTIALS']._serialized_start=751
  _globals['_AZURESTORAGECREDENTIALS']._serialized_end=856
  _globals['_SASTOKENCREDENTIALS']._serialized_start=858
  _globals['_SASTOKENCREDENTIALS']._serialized_end=942
# @@protoc_insertion_point(module_scope)
