# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/fitness_service/status.proto\x12\x14qwak.fitness.service\"\xa2\x01\n\tPodStatus\x12\x41\n\x12\x63ontainer_statuses\x18\x01 \x03(\x0b\x32%.qwak.fitness.service.ContainerStatus\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\t\x12\x0e\n\x06pod_id\x18\x06 \x01(\t\"\x9d\x01\n\x0f\x43ontainerStatus\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x15\n\rrestart_count\x18\x03 \x01(\x05\x12\x0f\n\x07started\x18\x04 \x01(\x08\x12=\n\x0f\x63ontainer_state\x18\x05 \x01(\x0b\x32$.qwak.fitness.service.ContainerState\"\x8f\x02\n\x0e\x43ontainerState\x12N\n\x17\x63ontainer_state_running\x18\x01 \x01(\x0b\x32+.qwak.fitness.service.ContainerStateRunningH\x00\x12T\n\x1a\x63ontainer_state_terminated\x18\x02 \x01(\x0b\x32..qwak.fitness.service.ContainerStateTerminatedH\x00\x12N\n\x17\x63ontainer_state_waiting\x18\x03 \x01(\x0b\x32+.qwak.fitness.service.ContainerStateWaitingH\x00\x42\x07\n\x05state\"+\n\x15\x43ontainerStateRunning\x12\x12\n\nstarted_at\x18\x01 \x01(\t\"\x9d\x01\n\x18\x43ontainerStateTerminated\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x11\n\texit_code\x18\x02 \x01(\x05\x12\x13\n\x0b\x66inished_at\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0e\n\x06signal\x18\x06 \x01(\x05\x12\x12\n\nstarted_at\x18\x07 \x01(\t\"8\n\x15\x43ontainerStateWaiting\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\tB#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.fitness_service.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _globals['_PODSTATUS']._serialized_start=60
  _globals['_PODSTATUS']._serialized_end=222
  _globals['_CONTAINERSTATUS']._serialized_start=225
  _globals['_CONTAINERSTATUS']._serialized_end=382
  _globals['_CONTAINERSTATE']._serialized_start=385
  _globals['_CONTAINERSTATE']._serialized_end=656
  _globals['_CONTAINERSTATERUNNING']._serialized_start=658
  _globals['_CONTAINERSTATERUNNING']._serialized_end=701
  _globals['_CONTAINERSTATETERMINATED']._serialized_start=704
  _globals['_CONTAINERSTATETERMINATED']._serialized_end=861
  _globals['_CONTAINERSTATEWAITING']._serialized_start=863
  _globals['_CONTAINERSTATEWAITING']._serialized_end=919
# @@protoc_insertion_point(module_scope)
