"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURE_NAMES_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """The name of the featureset"""
    @property
    def feature_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The name of the features"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        feature_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_names", b"feature_names", "featureset_name", b"featureset_name"]) -> None: ...

global___FeaturesetFeatures = FeaturesetFeatures
