# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_state_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_state_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/feature_store/features/feature_set_state_service.proto\x12\x1bqwak.feature.store.features\x1a\x33qwak/feature_store/features/feature_set_state.proto\"a\n\x1fGetFeatureSetStateByIdV1Request\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"k\n GetFeatureSetStateByIdV1Response\x12G\n\x11\x66\x65\x61ture_set_state\x18\x01 \x01(\x0b\x32,.qwak.feature.store.features.FeatureSetState\"e\n!GetFeatureSetStateByNameV1Request\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"m\n\"GetFeatureSetStateByNameV1Response\x12G\n\x11\x66\x65\x61ture_set_state\x18\x01 \x01(\x0b\x32,.qwak.feature.store.features.FeatureSetState\"\"\n GetFeatureSetStatesListV1Request\"l\n!GetFeatureSetStatesListV1Response\x12G\n\x11\x66\x65\x61ture_set_state\x18\x01 \x03(\x0b\x32,.qwak.feature.store.features.FeatureSetState\"\x81\x01\n\x1eUpdateFeatureSetStateV1Request\x12G\n\x11\x66\x65\x61ture_set_state\x18\x01 \x03(\x0b\x32,.qwak.feature.store.features.FeatureSetState\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"!\n\x1fUpdateFeatureSetStateV1Response\"!\n\x1f\x44\x65leteFeatureSetStateV1Response\"8\n\x1e\x44\x65leteFeatureSetStateV1Request\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t2\x93\x06\n\x16\x46\x65\x61tureSetStateService\x12\x95\x01\n\x16GetFeatureSetStateById\x12<.qwak.feature.store.features.GetFeatureSetStateByIdV1Request\x1a=.qwak.feature.store.features.GetFeatureSetStateByIdV1Response\x12\x9b\x01\n\x18GetFeatureSetStateByName\x12>.qwak.feature.store.features.GetFeatureSetStateByNameV1Request\x1a?.qwak.feature.store.features.GetFeatureSetStateByNameV1Response\x12\x98\x01\n\x17GetFeatureSetStatesList\x12=.qwak.feature.store.features.GetFeatureSetStatesListV1Request\x1a>.qwak.feature.store.features.GetFeatureSetStatesListV1Response\x12\x92\x01\n\x15UpdateFeatureSetState\x12;.qwak.feature.store.features.UpdateFeatureSetStateV1Request\x1a<.qwak.feature.store.features.UpdateFeatureSetStateV1Response\x12\x92\x01\n\x15\x44\x65leteFeatureSetState\x12;.qwak.feature.store.features.DeleteFeatureSetStateV1Request\x1a<.qwak.feature.store.features.DeleteFeatureSetStateV1ResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_state_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_GETFEATURESETSTATEBYIDV1REQUEST']._serialized_start=145
  _globals['_GETFEATURESETSTATEBYIDV1REQUEST']._serialized_end=242
  _globals['_GETFEATURESETSTATEBYIDV1RESPONSE']._serialized_start=244
  _globals['_GETFEATURESETSTATEBYIDV1RESPONSE']._serialized_end=351
  _globals['_GETFEATURESETSTATEBYNAMEV1REQUEST']._serialized_start=353
  _globals['_GETFEATURESETSTATEBYNAMEV1REQUEST']._serialized_end=454
  _globals['_GETFEATURESETSTATEBYNAMEV1RESPONSE']._serialized_start=456
  _globals['_GETFEATURESETSTATEBYNAMEV1RESPONSE']._serialized_end=565
  _globals['_GETFEATURESETSTATESLISTV1REQUEST']._serialized_start=567
  _globals['_GETFEATURESETSTATESLISTV1REQUEST']._serialized_end=601
  _globals['_GETFEATURESETSTATESLISTV1RESPONSE']._serialized_start=603
  _globals['_GETFEATURESETSTATESLISTV1RESPONSE']._serialized_end=711
  _globals['_UPDATEFEATURESETSTATEV1REQUEST']._serialized_start=714
  _globals['_UPDATEFEATURESETSTATEV1REQUEST']._serialized_end=843
  _globals['_UPDATEFEATURESETSTATEV1RESPONSE']._serialized_start=845
  _globals['_UPDATEFEATURESETSTATEV1RESPONSE']._serialized_end=878
  _globals['_DELETEFEATURESETSTATEV1RESPONSE']._serialized_start=880
  _globals['_DELETEFEATURESETSTATEV1RESPONSE']._serialized_end=913
  _globals['_DELETEFEATURESETSTATEV1REQUEST']._serialized_start=915
  _globals['_DELETEFEATURESETSTATEV1REQUEST']._serialized_end=971
  _globals['_FEATURESETSTATESERVICE']._serialized_start=974
  _globals['_FEATURESETSTATESERVICE']._serialized_end=1761
# @@protoc_insertion_point(module_scope)
