# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/featureset_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.qwak/execution/v1/state/featureset_state.proto\x12%qwak.feature.store.execution.v1.state\"A\n\x0f\x46\x65\x61turesetState\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\tB`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.featureset_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _globals['_FEATURESETSTATE']._serialized_start=89
  _globals['_FEATURESETSTATE']._serialized_end=154
# @@protoc_insertion_point(module_scope)
